@@ -137,50 +137,22 @@ public class Pleiades {
 		log = Logger.getLogger(Pleiades.class);
 		log.info("Pleiades 構成保管パス: " + pleiadesConfigurationPath);
 
-		Analyses.end(Pleiades.class, "init", start);
-	}
+		// 初回起動時実行コマンドの実行 (Windows のみ使用可能)
+		String initBatch = pleiadesOption.initBatch;
+		if (initBatch != null) {
+			File initBatchMarkFile = new File(pleiadesConfigurationPath, ".init.batch.processed");
+			if (!initBatchMarkFile.exists()) {
+				initBatchMarkFile.createNewFile();
 
-	// L&F 変更は問題が多いため廃止。2010.02.07
-	/**
-	 * Swing で使用するフォントを初期化します。
-	 * Eclipse のプラグインは通常 SWT が使用されていますが、
-	 * 一部のプラグインでは Swing も利用されています。
-	 * <p>
-	 * @throws ClassNotFoundException LookAndFeel クラスが見つからなかった場合
-	 * @throws InstantiationException クラスの新しいインスタンスを生成できなかった場合
-	 * @throws IllegalAccessException クラスまたは初期化子にアクセスできない場合
-	 * @throws UnsupportedLookAndFeelException lnf.isSupportedLookAndFeel() が false の場合
-	private static void initSwingFont() throws ClassNotFoundException,
-			InstantiationException, IllegalAccessException,
-			UnsupportedLookAndFeelException {
-
-		long start = System.nanoTime();
-
-		// LookAndFeel の設定
-		UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
-		Toolkit.getDefaultToolkit().setDynamicLayout(true);
-
-		// フォント設定
-		Object propoFont = new FontUIResource("MS UI Gothic",	Font.TRUETYPE_FONT, 12);
-		Object fixedFont = new FontUIResource("MS Gothic",		Font.TRUETYPE_FONT, 12);
-
-		// 一旦すべてのコンポーネントのフォントをプロポーショナルにする。
-		// フォントリソースかの判定は値を取得し instanceof FontUIResource が
-		// 安全だが、UIDefaults の Lazy Value を生かすため末尾の文字列で判定。
-		for (Object keyObj : UIManager.getLookAndFeelDefaults().keySet()) {
-			String key = keyObj.toString();
-			if (key.endsWith("font") || key.endsWith("Font")) {
-				UIManager.put(key, propoFont);
+				String cmd = "cmd /c start " + initBatch.replace('/', '\\');
+				File currentDir = new File(EclipseFiles.getHome(), initBatch.replaceFirst("[^/\\\\]+$", ""));
+				log.info("初回起動時実行コマンドの実行 コマンド:" + cmd + " カレントディレクトリ:" + currentDir);
+				Runtime.getRuntime().exec(cmd, null, currentDir);
 			}
 		}
 
-		// 特定コンポーネントのフォントを等幅にする
-		UIManager.put("TextPane.font", fixedFont);
-		UIManager.put("TextArea.font", fixedFont);
-
-		Analyses.end(Pleiades.class, "initSwingFont<THREAD>", start);
+		Analyses.end(Pleiades.class, "init", start);
 	}
-	 */
 
 	/**
 	 * 起動トランスフォーマーを開始します。
@@ -256,4 +228,46 @@ public class Pleiades {
 		}
 		return os;
 	}
+
+	// L&F 変更は問題が多いため廃止。2010.02.07
+	/**
+	 * Swing で使用するフォントを初期化します。
+	 * Eclipse のプラグインは通常 SWT が使用されていますが、
+	 * 一部のプラグインでは Swing も利用されています。
+	 * <p>
+	 * @throws ClassNotFoundException LookAndFeel クラスが見つからなかった場合
+	 * @throws InstantiationException クラスの新しいインスタンスを生成できなかった場合
+	 * @throws IllegalAccessException クラスまたは初期化子にアクセスできない場合
+	 * @throws UnsupportedLookAndFeelException lnf.isSupportedLookAndFeel() が false の場合
+	private static void initSwingFont() throws ClassNotFoundException,
+			InstantiationException, IllegalAccessException,
+			UnsupportedLookAndFeelException {
+
+		long start = System.nanoTime();
+
+		// LookAndFeel の設定
+		UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
+		Toolkit.getDefaultToolkit().setDynamicLayout(true);
+
+		// フォント設定
+		Object propoFont = new FontUIResource("MS UI Gothic",	Font.TRUETYPE_FONT, 12);
+		Object fixedFont = new FontUIResource("MS Gothic",		Font.TRUETYPE_FONT, 12);
+
+		// 一旦すべてのコンポーネントのフォントをプロポーショナルにする。
+		// フォントリソースかの判定は値を取得し instanceof FontUIResource が
+		// 安全だが、UIDefaults の Lazy Value を生かすため末尾の文字列で判定。
+		for (Object keyObj : UIManager.getLookAndFeelDefaults().keySet()) {
+			String key = keyObj.toString();
+			if (key.endsWith("font") || key.endsWith("Font")) {
+				UIManager.put(key, propoFont);
+			}
+		}
+
+		// 特定コンポーネントのフォントを等幅にする
+		UIManager.put("TextPane.font", fixedFont);
+		UIManager.put("TextArea.font", fixedFont);
+
+		Analyses.end(Pleiades.class, "initSwingFont<THREAD>", start);
+	}
+	 */
 }
