@@ -6,12 +6,12 @@
  */
 package jp.sourceforge.mergedoc.pleiades;
 
+import org.apache.commons.lang.StringUtils;
+
 import jp.sourceforge.mergedoc.pleiades.log.Logger;
 import jp.sourceforge.mergedoc.pleiades.log.Logger.Level;
 import jp.sourceforge.mergedoc.pleiades.resource.TranslationNotFoundProperties;
 
-import org.apache.commons.lang.StringUtils;
-
 /**
  * Pleiades 起動オプションです。
  * <p>
@@ -34,6 +34,9 @@ public class PleiadesOption {
 	/** ログ・レベル */
 	public Level logLevel = Level.INFO;
 
+	/** 初回起動時実行コマンド */
+	public String initBatch;
+
 	/**
 	 * 起動オプションを構築します。
 	 * <p>
@@ -64,6 +67,11 @@ public class PleiadesOption {
 					" のいずれかである必要があります。");
 			}
 		}
+
+		// 初回起動時実行コマンドの取得
+		if (arg.contains("init.batch=")) {
+			initBatch = arg.replaceFirst("^.*?init\\.batch\\=", "").replaceFirst(",.*$", "");
+		}
 	}
 
 	/**
