@@ -14,8 +14,10 @@ import java.io.FileInputStream;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.io.OutputStreamWriter;
+import java.io.Reader;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -25,6 +27,7 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Properties;
 import java.util.zip.Deflater;
@@ -32,11 +35,11 @@ import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
 import java.util.zip.ZipOutputStream;
 
-import jp.sourceforge.mergedoc.pleiades.log.Logger;
-
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 
+import jp.sourceforge.mergedoc.pleiades.log.Logger;
+
 /**
  * プロパティー・セット・クラスです。
  * このクラスは java.util.Properties と比較し、以下の利点があります。
@@ -66,6 +69,14 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 	public PropertySet() {
 	}
 
+	/**
+	 * プロパティー・セットを構築します。
+	 * @param initialCapacity 初期容量
+	 */
+	public PropertySet(int initialCapacity) {
+		super(initialCapacity);
+	}
+
 	/**
 	 * プロパティー・セットを構築します。
 	 * <p>
@@ -115,13 +126,15 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 	 * プロパティー・ファイルをロードします。
 	 * <p>
 	 * @param paths リソース・ルートからの相対パス
+	 * @return このインスタンス
 	 */
-	public void load(String... paths) {
+	public PropertySet load(String... paths) {
 
 		for (String path : paths) {
 			File file = Files.getFile(path);
 			load(file);
 		}
+		return this;
 	}
 
 	/**
@@ -131,8 +144,9 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 	 * *.properties、*.properties.zip がすべてロードされます。
 	 * <p>
 	 * @param files プロパティー・ファイルまたはディレクトリー
+	 * @return このインスタンス
 	 */
-	public void load(File... files) {
+	public PropertySet load(File... files) {
 
 		for (File file : files) {
 
@@ -148,6 +162,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 				loadFile(file);
 			}
 		}
+		return this;
 	}
 
 	/**
@@ -181,7 +196,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 	public void load(InputStream is) {
 
 		try {
-			loadInternal(is);
+	        loadUTF8(is);
 
 		} catch (IOException e) {
 			throw new IllegalArgumentException(e);
@@ -321,6 +336,19 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 		};
 	}
 
+	/*
+	 * Java8 では putAll から put が呼び出されなくなりました。
+	 * put がオーバーライドされている場合、以前のバージョンと同じように動作するように
+	 * オーバーライドしています。
+	 */
+	@Override
+	public void putAll(Map<? extends String, ? extends String> m) {
+
+		for (Entry<? extends String, ? extends String> entry : m.entrySet()) {
+			put(entry.getKey(), entry.getValue());
+		}
+	}
+
 	// -------------------------------------------------------------------------
 	// 以下、java.util.Properties の拡張
 
@@ -356,7 +384,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 			if (is == null) {
 				return;
 			}
-			loadInternal(is);
+	        loadUTF8(is);
 
 		} catch (IOException e) {
 			throw new IllegalArgumentException(e);
@@ -366,11 +394,12 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 		}
 	}
 
-	private void loadInternal(InputStream inStream) throws IOException {
+	private void loadUTF8(InputStream is) throws IOException {
+        load0(new LineReader(new InputStreamReader(is, "UTF-8")));
+	}
 
+	private void load0(LineReader lr) throws IOException {
 		char[] convtBuf = new char[1024];
-		LineReader lr = new LineReader(inStream);
-
 		int limit;
 		int keyLen;
 		int valueStart;
@@ -384,9 +413,12 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 			valueStart = limit;
 			hasSep = false;
 
+			// System.out.println("line=<" + new String(lineBuf, 0, limit) +
+			// ">");
 			precedingBackslash = false;
 			while (keyLen < limit) {
 				c = lr.lineBuf[keyLen];
+				// need check if escaped.
 				if ((c == '=' || c == ':') && !precedingBackslash) {
 					valueStart = keyLen + 1;
 					hasSep = true;
@@ -422,7 +454,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 	@SuppressWarnings("unchecked")
 	private List<String> store(OutputStream out, String comments) throws IOException {
 
-		BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(out, "8859_1"));
+		BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(out, "UTF-8"));
 		if (comments != null) {
 			writeln(writer, "#" + comments);
 		}
@@ -459,15 +491,17 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 
 	class LineReader {
 
-		public LineReader(InputStream inStream) {
-			this.inStream = inStream;
+		public LineReader(Reader reader) {
+			this.reader = reader;
+			inCharBuf = new char[8192];
 		}
 
-		byte[] inBuf = new byte[8192];
+		byte[] inByteBuf;
+		char[] inCharBuf;
 		char[] lineBuf = new char[1024];
 		int inLimit = 0;
 		int inOff = 0;
-		InputStream inStream;
+		Reader reader;
 
 		int readLine() throws IOException {
 			int len = 0;
@@ -482,7 +516,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 
 			while (true) {
 				if (inOff >= inLimit) {
-					inLimit = inStream.read(inBuf);
+					inLimit = reader.read(inCharBuf);
 					inOff = 0;
 					if (inLimit <= 0) {
 						if (len == 0 || isCommentLine) {
@@ -491,7 +525,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 						return len;
 					}
 				}
-				c = (char) (0xff & inBuf[inOff++]);
+				c = inCharBuf[inOff++];
 				if (skipLF) {
 					skipLF = false;
 					if (c == '\n') {
@@ -527,12 +561,14 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 						System.arraycopy(lineBuf, 0, buf, 0, lineBuf.length);
 						lineBuf = buf;
 					}
+					// flip the preceding backslash flag
 					if (c == '\\') {
 						precedingBackslash = !precedingBackslash;
 					} else {
 						precedingBackslash = false;
 					}
 				} else {
+					// reached EOL
 					if (isCommentLine || len == 0) {
 						isCommentLine = false;
 						isNewLine = true;
@@ -541,7 +577,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 						continue;
 					}
 					if (inOff >= inLimit) {
-						inLimit = inStream.read(inBuf);
+						inLimit = reader.read(inCharBuf);
 						inOff = 0;
 						if (inLimit <= 0) {
 							return len;
@@ -549,6 +585,8 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 					}
 					if (precedingBackslash) {
 						len -= 1;
+						// skip the leading whitespace characters in following
+						// line
 						skipWhiteSpace = true;
 						appendedLineBegin = true;
 						precedingBackslash = false;
@@ -580,6 +618,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 			aChar = in[off++];
 			if (aChar == '\\') {
 				aChar = in[off++];
+				/* native2ascii 変換しない
 				if (aChar == 'u') {
 					int value = 0;
 					for (int i = 0; i < 4; i++) {
@@ -619,6 +658,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 					}
 					out[outLen++] = (char) value;
 				} else {
+				*/
 					if (aChar == 't')
 						aChar = '\t';
 					else if (aChar == 'r')
@@ -628,7 +668,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 					else if (aChar == 'f')
 						aChar = '\f';
 					out[outLen++] = aChar;
-				}
+				//}
 			} else {
 				out[outLen++] = aChar;
 			}
@@ -692,6 +732,7 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 				outBuffer.append(aChar);
 				break;
 			default:
+				/* native2ascii 変換しない
 				if ((aChar < 0x0020) || (aChar > 0x007e)) {
 					outBuffer.append('\\');
 					outBuffer.append('u');
@@ -700,8 +741,9 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 					outBuffer.append(toHex((aChar >> 4) & 0xF));
 					outBuffer.append(toHex(aChar & 0xF));
 				} else {
+				*/
 					outBuffer.append(aChar);
-				}
+				//}
 			}
 		}
 		return outBuffer.toString();
@@ -711,11 +753,4 @@ public class PropertySet extends HashMap<String, String> implements Iterable<Pro
 		bw.write(s);
 		bw.newLine();
 	}
-
-	private static char toHex(int nibble) {
-		return hexDigit[(nibble & 0xF)];
-	}
-
-	private static final char[] hexDigit = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E',
-			'F' };
 }
