@@ -357,21 +357,12 @@ public class TranslationDictionaryTest extends TestCase {
 				"Project Validator that validates the Spring Config files (e.g. class and property names, referenced beans etc.)",
 				"Spring 構成ファイルを検証するプロジェクト・バリデーター (例 クラスとプロパティーの名前、 参照される bean など)");
 
-		// 全角混在
-		assertLookup("Space ( ・ )", "空白 ( ・ )");
-		assertLookup("Ideographic space ( ° )", "全角空白 ( ° )");
-		assertLookup("Tab ( ≫ )", "タブ ( ≫ )");
-		assertLookup("Carriage Return ( \u00a4 )", "復帰 ( \u00a4 )");
-		assertLookup("Line Feed ( ¶ )", "改行 ( ¶ )");
-		assertLookup("Convert Line Delimiters to Windows (CRLF, \\r\\n, 0D0A, \u00A4¶)",
-			"行区切り文字を Windows に変換 (CRLF, \\r\\n, 0D0A, \u00A4¶)");
-
-		// 全角混在
-		assertLookup("Space ( ・ )", "空白 ( ・ )");
-		assertLookup("Ideographic space ( ° )", "全角空白 ( ° )");
-		assertLookup("Tab ( ≫ )", "タブ ( ≫ )");
-		assertLookup("Carriage Return ( \u00a4 )", "復帰 ( \u00a4 )");
-		assertLookup("Line Feed ( ¶ )", "改行 ( ¶ )");
+		// 全角混在 (記号表記は AOP で変更可能にしたため訳から除外)
+		assertLookup("Space ( ・ )", "空白");
+		assertLookup("Ideographic space ( ° )", "全角空白");
+		assertLookup("Tab ( ≫ )", "タブ");
+		assertLookup("Carriage Return ( \u00a4 )", "復帰");
+		assertLookup("Line Feed ( ¶ )", "改行");
 		assertLookup("Convert Line Delimiters to Windows (CRLF, \\r\\n, 0D0A, \u00A4¶)",
 			"行区切り文字を Windows に変換 (CRLF, \\r\\n, 0D0A, \u00A4¶)");
 
@@ -394,5 +385,8 @@ public class TranslationDictionaryTest extends TestCase {
 		assertLookup(
 				"Displays the configuration model of root project 'a'.",
 				"ルート・プロジェクト 'a' の構成モデルを表示します。");
+
+		// 拡張子との使い分けが不可能、拡張子の可能性がある場合はエクステンションとする、他も同様
+		assertLookup("Extensions", "エクステンション");
 	}
 }
